/*
 * Copyright (c) 1998-2000 The Jgroup Team.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Library Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library Public License for more details.
 *
 * You should have received a copy of the GNU Library Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package jgroup;

import jgroup.reference.*;

/**
 * In order to be notified of membership events like view changes, an object
 * must implement this interface.
 *
 * @author  Alberto Montresor
 * @since Jgroup 0.1
 */
public interface  MembershipListener
extends           Listener
{

  /**
   *  Upcall invoked on the member when a view change occurs.
   *  @param view   the new view.
   *  @see jgroup.MembershipService
   */
  public void viewChange(View view);


  /**
   * Upcall that is invoked by the group membership service to notify
   * that the current view is not valid any more, and the group
   * membership service is trying to reach an agreement on a new view.
   * Currently not implemented.
   * @see jgroup.MembershipService
   */
  public void prepareChange();


  /**
   * Upcall that is invoked by Jgroup to acknowledge the fact that this
   * object has left the group. This method can be invoked only after
   * method <t>leave</t> has been invoked on the group membership
   * service.
   *
   * @see jgroup.MembershipService
   */
  public void leaved();

} // END MembershipListener
