/*
 * Copyright (c) 1998-2000 The Jgroup Team.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Library Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library Public License for more details.
 *
 * You should have received a copy of the GNU Library Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package jgroup;

/**
 * The facilities provided by the group membership service included
 * in Jgroup may be accessed using the <tt>MembershipService</tt>
 * interface. Methods in this interfaces enable objects to become
 * members of a group and subsequentially leave it. <p>
 *
 * Instances of <tt>MembershipService</tt> may be obtained through
 * the <tt>GroupManager</tt> class.
 *
 * @author  Alberto Montresor
 * @since   Jgroup 0.1
 */
public interface        MembershipService
{


  /**
   * Requests to join a group identified by <tt>gid</tt>.  <p>
   *
   * When requesting a group manager, a server may specify a port number to be
   * used through a <tt>jgroup.TransportConfig</tt> object. Each specified
   * port number in a Java virtual machine is controlled by a transport layer.
   * Multiple objects joining different groups may share the facilities
   * provided by a single transport layer by using the same communication
   * port when requesting a group manager. In this case, the group identifier
   * is used to distinguish multiple groups.
   *
   * @param gid   Non-negative integer identifying the group
   *
   * @exception IllegalArgumentException
   *            If <tt>gid</tt> is negative.
   * @exception JgroupException
   *            if the group manager receives a request to join a group for which it
   *            is already member.
   */
  public void join(int gid)
    throws JgroupException;


  /**
   * Requests to join the default group. <p>
   *
   * When each group is associated to a distinct communication port,
   * servers may join a group using a default group identifier.
   *
   * @exception JgroupException
   *            if the group manager receives a request to join a group for which it
   *            is already member.
   */
  public void join()
    throws JgroupException;


  /**
   * Request to leave a group. Note that an object member may receive event
   * notifications such as view installations for a group even after having
   * request to leave the group itself. However, the member will eventually
   * leave the group. When this happens, its method <tt>leaved</tt> is invoked.
   * After this invocation, the member will not receive any event notification
   * related to the group.
   *
   * @exception JgroupException   If the group manager is not member of any group,
   *                              or is already leaving its current group.
   */
  public void leave()
    throws JgroupException;


  /**
   * Returns the member identifier of the member.
   */
  public MemberId getMyIdentifier();


  /**
   * Returns a <tt>MemberTable</tt> helper that will notified by the
   * object.
   */
  public MemberTable getMemberTable();


} // END MembershipService
