/*
 * Copyright (c) 1998-2000 The Jgroup Team.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Library Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library Public License for more details.
 *
 * You should have received a copy of the GNU Library Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package jgroup;

import java.net.*;

/**
 * An instance of this class uniquely identifies a Java virtual machine.
 * Each <tt>VMID</tt> is composed by an IP address and an
 * incarnation time.
 *
 *  @author Alberto Montresor
 *  @since    Jgroup 0.7
 */
public interface VMID
{


  /**
   *  Returns the IP address of the host in which the virtual machine
   *  identified by this <code>VMID</code> is executed.
   */
  public InetAddress getAddress()
    throws UnknownHostException;


  /**
   * Returns an object that can be used as hash key for the
   * address of the host in which the virtual machine identified
   * by this <code>VMID</code> is executed. <p>
   *
   * In the Relacs implementation, this is more efficient than
   * using the <tt>InetAddress</tt> provided by <tt>getAddress</tt>.
   */
  public Object getHashAddress();


  /**
   *  Returns the time at which this <code>VMID</code> has been created.
   */
  public long getTime();


} // END VMID




