/*
 * Copyright (c) 1998-2000 The Jgroup Team.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Library Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library Public License for more details.
 *
 * You should have received a copy of the GNU Library Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package jgroup;

/**
 *  The Partitionable Group Membership Service contained in Jgroup
 *  tracks changes in the group's composition and installs them as
 *  views at member objects. Installated views are an abstraction of
 *  the current environment with respect to failures and recoveries.
 *  Member objects can obtain information about the current view
 *  through the <code>View</code> interface.
 *  Each view is uniquely identified by a view identifier, that can
 *  be obtained by invoking method <code>getVid</code>. The
 *  composition of the view may be obtained by invoking method
 *  <code>getMembers</code>.
 *
 * @author  Alberto Montresor
 * @since   Jgroup 0.1
 */
public interface View
{

  /**
   *  Returns the identifier of the group for which this view has been
   *  generated.
   */
  int getGid();


  /**
   *  Returns the identifier of this view.
   */
  long getVid();

  /**
   *  Returns an array of <code>MemberId</code>s identifying the members
   *  included in this view.
   */
  MemberId[] getMembers();

} // END View

