/*
 * Copyright (c) 1998-2000 The Jgroup Team.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Library Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library Public License for more details.
 *
 * You should have received a copy of the GNU Library Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package relacs.daemon;

import relacs.general.OrderedList;
import relacs.mss.*;
import debug.Debug;


/**
* The <code> MsgGroup</code> class
*
* @author  Alberto Montresor
* @since   Jgroup 0.1
*/
final class MsgGroup
{

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Unique message instance
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   * As these messages are never stored by the daemon, a single message instance is
   * sufficient. In this way, we save the costs of allocating and garbage collecting
   * messages.
   */
  private static MsgGroup msg;

  static {
    msg = new MsgGroup();
  }

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Fields
  ////////////////////////////////////////////////////////////////////////////////////////////

  /** List of host identifiers associated with the group */
  int[]                 hosts;



  ////////////////////////////////////////////////////////////////////////////////////////////
  // Methods
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   * Returns a <code>MsgGroup</code> object that contains the decoding of the m-received input
   * stream.
   *
   * @param msgstream   the message input stream to decode
   */
  static MsgGroup decode(InMessage msgstream)
  {
    int len  = Types.readGrp(msgstream);
    msg.hosts = new int[len];
    for (int i=0; i<len; i++)
      msg.hosts[i] = Types.readHid(msgstream);
    return msg;
  }


  /**
   * Returns a output stream containing the encoding of a <code>MsgGroup</code> message.
   *
   * @param     gid       group identifier
   */
  static OutMessage encode(MsgFactory mfactory, int gid, OrderedList list)
  {
    // Count members in list
    int count = 0;
    if (list != null)
      count = list.count();

    // Allocates data buffer
    int size = Types.GID_SIZE + Types.GRP_SIZE + count * Types.HID_SIZE;
    OutMessage msgstream = mfactory.get(size);

    Types.writeGid(msgstream, gid);
    Types.writeGrp(msgstream, count);
    if (list != null) {
      OrderedList scan = list.getFirst();
      while (scan != null) {
        Types.writeHid(msgstream, scan.key);
        scan = scan.getNext();
      }
    }

    return msgstream;
  }


  void print()
  {
    if (Debug.DEBUG) {
      Debug.print(20, "Message R_GROUP: Hosts:");
      for (int i=0; i<hosts.length; i++)
        Debug.print(20, " "+ hosts[i]);
      Debug.println(20, "");
    }
  }

} // END MsgGroup









