/*
 * Copyright (c) 1998-2000 The Jgroup Team.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Library Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library Public License for more details.
 *
 * You should have received a copy of the GNU Library Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

/*
 *  History:
 *  22/11/2000: Added field sid, used to distinguish messages with
 *    the same id but originated by different senders.
 */

package relacs.daemon;

import relacs.mss.Upcall;

/**
 * The <code> UpcallDlvrAck</code> class represents a local message exchanged between
 * members and the daemon; it is used by the member to notify the daemon of ...
 *
 * @author  Alberto Montresor
 * @since   Jgroup 0.1
 */
final class     UpcallDlvrAck
extends         Upcall
implements      Tag
{

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Fields
  ////////////////////////////////////////////////////////////////////////////////////////////

  int           hpos;           // Host position of the member in the previous view
  int           mpos;           // Local member position of the member in the previous view
  int           vpos;           // Member position of the member in the previous view
  int           mid;            // Message identifier
  long          sid;            // Identifier of the sender of the original message
  Object        result;         // Result value

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constructors
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   * Creates a <code> UpcallDlvrAck</code> upcall.
   */
  UpcallDlvrAck(int gid, int hpos, int mpos, int vpos, int mid, long sid, Object result)
  {
    super(L_DLVRACK, gid);
    this.hpos   = hpos;
    this.mpos   = mpos;
    this.vpos   = vpos;
    this.mid    = mid;
    this.sid    = sid;
    this.result = result;
  }

} // END UpcallDlvrAck

