/*
 * Copyright (c) 1998-2000 The Jgroup Team.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Library Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library Public License for more details.
 *
 * You should have received a copy of the GNU Library Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package relacs.daemon;

import jgroup.*;


/**
 * The <code>ViewImpl</code> class implements the <code>jgroup.View</code> interface.
 *
 * @author  Alberto Montresor
 * @since   Jgroup 0.1
 */
public class            ViewImpl
implements              View
{

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Fields
  ////////////////////////////////////////////////////////////////////////////////////////////

  private int           gid;            // Group identifier
  private long          vid;            // View identifier
  private MemberId[]    members;        //


  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constructors
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   * Creates a view composed by a single member and a single host; used
   * to initialize members joining to a group.
   */
  ViewImpl(int gid, long vid, MemberId me)
  {
    this.gid     = gid;
    this.vid     = vid;
    members = new MemberId[1];
    members[0] = me;
  }

  /**
   * Creates a view composed by a set of hosts and members; used to create
   * new view after receiving view messages.
   */
  ViewImpl(int gid, long vid, MemberId[] members)
  {
    this.gid     = gid;
    this.vid     = vid;
    this.members = members;
  }

  /**
   * Clones a view.
   */
  ViewImpl(View v)
  {
    this.gid     = v.getGid();
    this.vid     = v.getVid();
    this.members = v.getMembers();
  }

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Methods
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   *  Returns the identifier of the group for which this view has been
   *  generated.
   */
  public int            getGid()
  {
    return gid;
  }

  /**
   * Returns the identifier of this view
   */
  public long           getVid()
  {
    return vid;
  }

  /**
   *  Returns an array of <code>MemberId</code>s identifying the members
   *  included in this view.
   */
  public MemberId[] getMembers()
  {
    return (MemberId[]) members.clone();
  }

  /**
   * Compares two <code>View</code>s for content equality.
   *
   * @param obj the Object to compare with
   * @return  true if these Objects are equal; false otherwise.
   */
  public boolean equals(Object obj) {
    if ((obj != null) && (obj instanceof ViewImpl)) {
      ViewImpl view = (ViewImpl) obj;
      return (gid == view.gid && vid == view.vid);
    }
    return false;
  }

} // END ViewImpl



