/*
 * Copyright (c) 1998-2000 The Jgroup Team.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Library Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library Public License for more details.
 *
 * You should have received a copy of the GNU Library Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

/*
 *  History:
 *  22/11/2000: Added field sid, used to distinguish messages with
 *    the same id but originated by different senders.
 */

package relacs.gm;

import java.io.*;
import relacs.mss.Upcall;

/**
 * The <code> UpcallDlvr</code> class represents a local message exchanged between
 * members and the daemon; it is used by the daemon to inform members of an
 * application message that must be delivered, or by a member to inform the daemon
 * that the message has been delivered.
 *
 * @author  Alberto Montresor
 * @since   Jgroup 0.1
 */
final class     UpcallDlvr
extends         Upcall
implements      GMTag
{

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Fields
  ////////////////////////////////////////////////////////////////////////////////////////////

  boolean       flag;               // Single object flag
  long          vid;                // Current view identifier
  int           hpos;               // Host index
  int           mid;                // Message identifier
  long          sid;                // Identifier of the sender of the original message
  boolean       ackr;               // True if an ack for this message is needed
  InputStream   stream;             // Message contents


  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constructors
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   * Creates an incomplete UpcallDlvr structure; the lid and mpos fields
   * will be filled up by the member when responding.
   */
  UpcallDlvr(int gid, boolean flag, long vid, int hpos, int mid, long sid, 
    boolean ackr, InputStream stream)
  {
    super(L_DLVR, gid);
    this.flag   = flag;
    this.vid    = vid;
    this.hpos   = hpos;
    this.mid    = mid;
    this.sid    = sid;
    this.ackr   = ackr;
    this.stream = stream;
  }

} // END UpcallDlvr
