/*
 * Copyright (c) 1998-2000 The Jgroup Team.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Library Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library Public License for more details.
 *
 * You should have received a copy of the GNU Library Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package relacs.rmi;

import java.lang.reflect.*;
import java.util.*;

import jgroup.*;

/**
 * Helper class usueful to associate a "method hash" to each of the methods
 * contained in a set of interfaces. The method hash is a long containing
 * the first 64 bits of the SHA digest from the UTF encoded string of the
 * method name and descriptor. Spiegare implementazione
 *
 * @author  Alberto Montresor (Partly copied from Java 2 SDK 1.3)
 * @since   Jgroup 0.9
 */
final class ClientMethodTable
{
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Fields
  ////////////////////////////////////////////////////////////////////////////////////////////

  private HashMap   table;


  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constructors
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   * Create an empty method table.
   */
  ClientMethodTable()
  {
    table = new HashMap();
  }


  ////////////////////////////////////////////////////////////////////////////////////////////
  // Methods
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   *  Implementation note: this method does not need to be synchronized, because concurrent
   *  invocations of it are idempotent. Clearly, computing twice or more times the same
   *  method hash is not efficient, but this event is rare.
   */
  MethodInfo get(Method m)
  {
    MethodInfo info = (MethodInfo) table.get(m);
    if (info == null) {
      info = new MethodInfo(m);
      table.put(m, info);
    }
    return info;
  }

} // END ClientMethodTable

