/*
 * Copyright (c) 1998-2000 The Jgroup Team.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Library Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library Public License for more details.
 *
 * You should have received a copy of the GNU Library Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package relacs.rmi;

import java.net.*;
import java.rmi.*;
import java.util.*;

import jgroup.*;

import debug.Debug;

public final class    IIDTable
{

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Fields
  ////////////////////////////////////////////////////////////////////////////////////////////

  Hashtable       table;

  /** Identifier of this member */
  MemberId        me;


  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constructors
  ////////////////////////////////////////////////////////////////////////////////////////////

  IIDTable(MemberId me)
  {
    table = new Hashtable();
    this.me = me;
  }

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Methods
  ////////////////////////////////////////////////////////////////////////////////////////////


  synchronized IIDEntry insert(IIDImpl id)
    throws RemoteException
  {
    Record    record;
    IIDEntry  scan = null;

    record = (Record) table.get(id.getVmid().getHashAddress());
    if (record == null) {
      if (Debug.DEBUG)
        Debug.println(40, "IIDTable: new client, new record");
      record = new Record();
      record.time = id.getVmid().getTime();
      record.list = new IIDEntry();
      table.put(id.getVmid().getHashAddress(), record);
    }
    if (id.getVmid().getTime() > record.time) {
      // Remove all the results, as the client has a new incarnation.
      if (Debug.DEBUG)
        Debug.println(40, "IIDTable: new incarnation");
      record.list = new IIDEntry();
      record.time = id.getVmid().getTime();
      record.ack = id.getAck();
    } else if (id.getAck() > record.ack) {
      // Remove all the results that have been acknowledged
      if (Debug.DEBUG)
        Debug.println(40, "IIDTable: remove ack");
      record.list.removeAll(id.getAck());
      record.ack = id.getAck();
    }
    if (id.getCounter() >= record.ack) {
      Object obj = record.list.lookup(id.getCounter());
      if (obj == null) {
        if (Debug.DEBUG)
          Debug.println(40, "IIDTable: new record");
        scan = new IIDEntry(id, me);
        record.list.insert(scan);
      }
      else {
        if (Debug.DEBUG)
          Debug.println(40, "IIDTable: existing entry");
        scan = (IIDEntry) obj;
      }
      return scan;
    }
    else {
      throw new RemoteException("Method invocation already executed");
    }
  }


  ////////////////////////////////////////////////////////////////////////////////////////////
  // Record class
  ////////////////////////////////////////////////////////////////////////////////////////////

  private class Record
  {
    long      time;
    int       ack;
    IIDEntry  list;
  }


} // END IIDTable
