/*
 * Copyright (c) 1998-2000 The Jgroup Team.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Library Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library Public License for more details.
 *
 * You should have received a copy of the GNU Library Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package relacs.rmi.registry;

import java.rmi.*;
import java.rmi.server.*;
import java.lang.reflect.*;

import relacs.general.*;
import relacs.rmi.*;
import relacs.rmi.proxy.*;


/**
 *
 *
 * @author  Alberto Montresor
 * @since   Jgroup 0.5
 */
final class     ServiceData
{

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Fields
  ////////////////////////////////////////////////////////////////////////////////////////////

  static Class[]  types = new Class[1];
  static Object[] arguments = new Object[1];

  static {
    try {
      types[0] = Class.forName("java.rmi.server.RemoteRef");
    } catch (ClassNotFoundException e) {
      throw new NoClassDefFoundError(e.getMessage());
    }
  }

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Fields
  ////////////////////////////////////////////////////////////////////////////////////////////

  private Class           serverClass;  // List of interfaces implemented by this object
  private LinkedList      list;         // List of bindings


  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constructor
  ////////////////////////////////////////////////////////////////////////////////////////////

  ServiceData(Class serverClass)
    throws RemoteException
  {
    this.serverClass = serverClass;
    list = new LinkedList();
  }


  ////////////////////////////////////////////////////////////////////////////////////////////
  // Methods
  ////////////////////////////////////////////////////////////////////////////////////////////

  void insert(BindingList bl)
    throws RemoteException
  {
    checkClass(bl.getClass());
    list.insert(bl);
  }

  /**
   *  Verificare che questo faccia esattamente cio' che ci aspettiamo.
   */
  void remove(BindingList bl)
  {
    list.remove(bl);
  }

  boolean isEmpty()
  {
    return list.isEmpty();
  }


  Remote getStub()
    throws RemoteException
  {
    LinkedList    scan;
    BindingList   bl;

    ExtGroupHandler2 handler = (ExtGroupHandler2) Exporter.getHandler();
    Remote proxy = Exporter.getProxy(serverClass, handler);

    scan = list.getFirst();
    while (scan != null) {
      bl = (BindingList) scan.getObj();
      handler.insert(bl.remote);
      scan = scan.next();
    }
    return proxy;
  }

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Private methods
  ////////////////////////////////////////////////////////////////////////////////////////////

  private void checkClass(Class cl)
    throws RemoteException
  {
  }


} // End ServiceData
