/*
 * Copyright (c) 1998-2000 The Jgroup Team.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Library Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library Public License for more details.
 *
 * You should have received a copy of the GNU Library Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package test.multicast;

import java.io.*;
import java.net.*;

import jgroup.*;
import jgroup.multicast.*;
import debug.Debug;

public class Performer
implements MembershipListener, MulticastListener
{

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Exchanged message
  ////////////////////////////////////////////////////////////////////////////////////////////

  static byte[] data = new byte[51200*1];

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Fields
  ////////////////////////////////////////////////////////////////////////////////////////////

  GroupManager        gm;
  MembershipService   membershipService;
  MulticastService    multicastService;
  View                view;
  int                 counter;
  long                time;
  int                 me;

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constructor
  ////////////////////////////////////////////////////////////////////////////////////////////

  Performer(String hostfile)
        throws JgroupException, IOException
  {
    Object[] configuration = new Object[] { new DistributedSystem(hostfile) };
    Object[] listeners = new Object[] { this };
    gm = GroupManager.getGroupManager(configuration, listeners);
    membershipService = (MembershipService) gm.getService(MembershipService.class);
    multicastService = (MulticastService) gm.getService(MulticastService.class);
    membershipService.join(7);
    view = null;
    counter = 0;
  }


  ////////////////////////////////////////////////////////////////////////////////////////////
  // Main method
  ////////////////////////////////////////////////////////////////////////////////////////////

  public static void main(String[] argv)
    throws Exception
  {
    if (argv.length < 2) {
      System.out.println("Usage: java test.multicast.Performer <hostfile> <debuglevel>");
      return;
    }
    Performer t = new Performer(argv[0]);
  }

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Upcalls
  ////////////////////////////////////////////////////////////////////////////////////////////

  public void viewChange(View view)
  {
    MemberId[] members = view.getMembers();

    time = System.currentTimeMillis();
    counter = 0;
    Debug.print("Vista: Vid" + view.getVid() + " Comp: ");
    for (int i=0; i < members.length; i++)
      Debug.print(members[i] + ", ");
    Debug.println("");

    if (me == 0 && this.view == null) {
      this.view = view;
      try {
        data[0] = (byte) (System.currentTimeMillis() & 0xFF);
        data[data.length-1] = data[0];
        multicastService.mcast(data, null);
      } catch (Exception e) {
        Debug.println("Mcast exception: " + e);
        System.exit(1);
      }
    }
  }


  public Object deliverStream(InputStream stream)
  {
    return null;
  }


  public Object deliverObject(Object msg)
  {
    byte[] data = (byte[]) msg;

    Debug.print("+");
    if (me == 0) {
      try {
        data[0] = (byte) (System.currentTimeMillis() & 0xFF);
        data[data.length-1] = data[0];
        multicastService.mcast(data, null);
      } catch (Exception e) {
        Debug.println("Mcast exception: " + e);
        System.exit(1);
      }
    }
    counter++;
    if (counter % 100 == 0)
      Debug.println("\nMessages: " + counter + " Msg/sec: " + (float) counter / ((System.currentTimeMillis()-time)/1000));
    return null;
  }


  public void prepareChange()
  {
  }


  public void leaved()
  {
  }

}
