/*
 * Copyright (c) 1998-2000 The Jgroup Team.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Library Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library Public License for more details.
 *
 * You should have received a copy of the GNU Library Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package test.performance;

import java.io.*;
import java.net.*;
import java.rmi.*;
import java.rmi.server.*;
import java.rmi.registry.*;
import java.util.*;

/**
 *  Implementation class of the Executor interface.
 *
 *  @author  Alberto Montresor
 *  @since   Jgroup 1.1
 */
public class ExecImpl
implements Executor
{

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Static section
  ////////////////////////////////////////////////////////////////////////////////////////////

  public static void main(String[] args)
    throws Exception
  {
    ExecImpl exec = new ExecImpl();
    while (true) {
      try { Thread.sleep(0x7fffffffffffffffL); } catch(InterruptedException ex) {}
    }
  }

  /** Should be approximately equal to 1/1/2000-00:00:00 */
  private static long START_TIME = 1000L * 86400 * (365*30+7);

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Fields
  ////////////////////////////////////////////////////////////////////////////////////////////

  /** Mapping from service identifier to server objects */
  private HashMap map;

  /** Counter to generate next service identifier */
  private int counter;

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constructor
  ////////////////////////////////////////////////////////////////////////////////////////////

  public ExecImpl()
    throws Exception
  {
    System.out.println("Starting executor");
    map = new HashMap();
    counter = 0;
    try {
      String name = InetAddress.getLocalHost().toString();
      int t1 = name.indexOf('.');
      int t2 = name.indexOf('/');
      t1 = (t1 < t2 ? t1 : t2);
    } catch (Exception e) {
      e.printStackTrace();
    }
    UnicastRemoteObject.exportObject(this);
    Registry registry = LocateRegistry.createRegistry(Registry.REGISTRY_PORT+1);
    registry.bind("ExecServer", this);
  }

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Methods from Executor
  ////////////////////////////////////////////////////////////////////////////////////////////

  // Javadoc comment inherited from interface Exec
  public Object start(Class c, Object[] args)
    throws RemoteException, Exception
  {
    System.out.print(new Date() + ": ");
    System.out.println("Start " + c.getName() + " Id: " + counter);
    Object id = new Integer(counter++);
    Server server = (Server) c.newInstance();
    server.start(args);
    map.put(id, server);
    return id;
  }


  // Javadoc comment inherited from interface Exec
  public void halt()
    throws RemoteException, Exception
  {
		// FIXME Invoke halt() on all servers
    new Thread() {
      public void run() {
        try {
          sleep(3000);
        } catch (InterruptedException e) {
        }
        System.exit(0);
      }
    }.start();
  }
	


  // Javadoc comment inherited from interface Exec
  public void halt(Object id)
    throws RemoteException, Exception
  {
    Server server = (Server) map.get(id);
    if (server != null)
      server.halt();
  }

  // Javadoc comment inherited from interface Exec
  public void clear()
    throws RemoteException, Exception
  {
    Iterator i = map.values().iterator();
    while (i.hasNext()) {
      Server server = (Server) i.next();
      server.halt();
    }
    map.clear();
  }

} // END ExecImpl





