/*
 * Copyright (c) 1998-2000 The Jgroup Team.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Library Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library Public License for more details.
 *
 * You should have received a copy of the GNU Library Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package test.performance;

import jgroup.*;
import jgroup.registry.*;
import test.performance.*;

/**
 *  Enable the starting of a dependable registry instance on
 *  a remote machine. Based on the <t>Server</t> interface.
 *
 *  @author  Alberto Montresor
 *  @since   Jgroup 1.1
 */
public class RegistryStarter
implements Server
{

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Fields
  ////////////////////////////////////////////////////////////////////////////////////////////

  DependableRegistry registry;


  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constructor
  ////////////////////////////////////////////////////////////////////////////////////////////

  public RegistryStarter()
  {
  }


  ////////////////////////////////////////////////////////////////////////////////////////////
  // Methods from Server
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   *  Start a dependable registry server
   */
  public void start(Object[] args)
    throws Exception
  {
    if (args == null || args.length != 1)
      throw new IllegalArgumentException("Argument required: distributed system");
    if (!(args[0] instanceof DistributedSystem))
      throw new IllegalArgumentException("The argument is not a distributed system");
    registry = RegistryFactory.getRegistry((DistributedSystem) args[0]);
    if (registry == null)
      registry = RegistryFactory.createRegistry(args);
  }


  /**
   *  Force the server object to stop
   */
  public void halt()
    throws Exception
  {
    // registry.halt() // TODO
    registry = null;
  }


} // END Server

